#LEFT LATERAL FAULTS

#theoretically, left lateral faults should be striking 222 to accomodate 102-directed spreading. norm should strike 012 and RL should strike 162
#bootstrap normal, right and left lateral faults far from the HFF to see if they differ significantly from predicted orientations
source("/users/natalie/desktop/geo/iceland/geologyGeometry/loadStructures2018.R")

#All of the small faults 
farLL <- filter(allSlicks, slipSense=="L", distance > 20000)
farRL <- filter(allSlicks, slipSense=="R", distance > 20000)
farRL <- farRL[-33,] #remove one outlier with a strike of 77
farRL <- farRL[-16,] #another outlier with a dip of 42
farN <- filter(allSlicks, slipSense == "N", distance > 20000)
allSlicks$strikeDeg <- lapply(allSlicks$pole, geoStrikeDipDegFromCartesian)
allSlicks$dipDeg <- lapply(allSlicks$strikeDeg, function(x) x[[2]])
allSlicks$strikeDeg <- lapply(allSlicks$strikeDeg, function(x) x[[1]])
farN_1a <- filter(allSlicks, slipSense == "N", distance > 20000, strikeDeg <90)
farN_1b <- filter(allSlicks, slipSense == "N", distance > 20000, strikeDeg >270)
farN_2 <- filter(allSlicks, slipSense == "N", distance > 20000, strikeDeg > 90, strikeDeg < 270)
farN_1 <- rbind(farN_1a, farN_1b)

#analysis of fault plane directions:

#RL BOOTSTRAPPING
RLpoleInfer <- lineBootstrapInference(farRL$pole, 10000)
lineEqualAreaPlot(farRL$pole, colors="yellow")
par(new=TRUE)
lineEqualAreaPlot(list(RLpoleInfer$center))
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(162, 90))), colors="blue")
RLpoleInfer$pvalueLine(geoCartesianFromStrikeDipDeg(c(162, 90)))
geoStrikeDipDegFromCartesian(RLpoleInfer$center) 

#RL BINGHAM INFERENCE:
pdf(paste("farRLBingCRandPred.pdf", sep = ""), useDingbats = FALSE, width = 10, height = 6)
par(pty="s")
par(mar=c(1,1,1,1))
RPoleBingInfer <- lineBinghamInference(farRL$pole, numPoints = 1000)
lineEqualAreaPlot(RPoleBingInfer$points)
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(162, 90))), colors="red")
dev.off()

#prediction plots within 95% confidence region according to bingham inference. 

#LL BOOTSTRAPPING
LLpoleInfer <- lineBootstrapInference(farLL$pole, 10000)
lineEqualAreaPlot(farLL$pole, colors="yellow")
par(new=TRUE)
lineEqualAreaPlot(list(LLpoleInfer$center))
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(222, 90))), colors="blue")
LLpoleInfer$pvalueLine(geoCartesianFromStrikeDipDeg(c(222, 90)))
geoStrikeDipDegFromCartesian(LLpoleInfer$center) 

#LL BINGHAM INFERENCE
LPoleBingInfer <- lineBinghamInference(farLL$pole, numPoints = 1000)

pdf(paste("farLLBingCRandPred.pdf", sep = ""), useDingbats = FALSE, width = 10, height = 6)
par(pty="s")
par(mar=c(1,1,1,1))
lineEqualAreaPlot(LPoleBingInfer$points)
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(222, 90))), colors="red")
dev.off()
 


#N BOOTSTRAPPING
#TOGETHER
NpoleInfer <- lineBootstrapInference(farN$pole, 10000)
lineEqualAreaPlot(list(NpoleInfer$center))
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(012, 90))), colors="blue")
NpoleInfer$pvalueLine(geoCartesianFromStrikeDipDeg(c(012, 90)))
geoStrikeDipDegFromCartesian(NpoleInfer$center)  
#when considered together, normal faults are not significantly different. This analysis isn't great because it averages out the dips of the 2 populations, but it seems to work. 

#SEPARATE
#if farN1_a and farN_3 don't exist, check predictions.Rmd
N1poleInfer <- lineBootstrapInference(farN_1a$pole, 10000) #11 observations
lineEqualAreaPlot(list(N1poleInfer$center))
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(012, 70))), colors="blue")
N1poleInfer$pvalueLine(geoCartesianFromStrikeDipDeg(c(012, 70)))
geoStrikeDipDegFromCartesian(N1poleInfer$center)  

N2poleInfer <- lineBootstrapInference(farN_3$pole, 10000) #14 observations
lineEqualAreaPlot(list(N2poleInfer$center))
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(192, 70))), colors="blue")
N2poleInfer$pvalueLine(geoCartesianFromStrikeDipDeg(c(192, 70)))
geoStrikeDipDegFromCartesian(N2poleInfer$center)  
#not really enough observations to justify bootstrapping for a confidence interval. When they're all taken together, it's closer. We would expect a 95% confidence region to contain the mean less than 95% of the time, so we would expect the test to reject too much I think-- it has too much confidence in itself. So it might still not be distinguishable from the prediction even if it says it is.

#N BINGHAM INFERENCE:
#ALL TOGETHER:
NPoleBingInfer <- lineBinghamInference(farN$pole, numPoints = 1000)

pdf(paste("farNBingCRandPred.pdf", sep = ""), useDingbats = FALSE, width = 10, height = 6)
par(pty="s")
par(mar=c(1,1,1,1))
lineEqualAreaPlot(NPoleBingInfer$points)
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(012, 90))), colors="red")
dev.off()

#SEPARATELY
N1PoleBingInfer <- lineBinghamInference(farN_1$pole, numPoints = 1000)
lineEqualAreaPlot(N1PoleBingInfer$points)
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(012, 70))), colors="red")

N2PoleBingInfer <- lineBinghamInference(farN_2$pole, numPoints = 1000)
lineEqualAreaPlot(N2PoleBingInfer$points)
par(new=TRUE)
lineEqualAreaPlot(list(geoCartesianFromStrikeDipDeg(c(192, 70))), colors="red")


#we try to average orientations anyway:
inferLL <- oriBootstrapInference(farLL$Rots, numBoots=10000, group=oriRayInPlaneGroup)
Lpole <- inferLL$center[1,]
LbootPoles <- lapply(inferLL$bootstraps, function(x) x[1,])
lineEqualAreaPlot(farLL$pole, colors="blue")
par(new=TRUE)
lineEqualAreaPlot(list(bootPoles))
par(new=TRUE)
lineEqualAreaPlot(list(pole))

inferLL$pvalueOri(inferLL$bootstraps[[2]])
rotEqualAnglePlot(inferLL$bootstraps)

inferRL <- oriBootstrapInference(farRL$Rots, numBoots=10000, group=oriRayInPlaneGroup)
Rpole <- inferRL$center[1,]
RbootPoles <- lapply(inferRL$bootstraps, function(x) x[1,])
lineEqualAreaPlot(farRL$pole, colors="blue")
par(new=TRUE)
lineEqualAreaPlot(list(RbootPoles)) #cant get bootstrapped fault poles to plot
par(new=TRUE)
lineEqualAreaPlot(list(Rpole), colors="red") # but the mean looks very nice

geoStrikeDipRakeDegFromRotation(inferRL$center)
#this returns 330.93, 87.42, 95.85. The 95.85 rake makes me think it is wrong but the pole seems reasonable. 
RLpred <- geoRotationFromStrikeDipRakeDeg(c(162, 90, 0))
inferRL$pvalueOri(RLpred)
#this returns a p-value of 0 for the null hypothesis that the predicted orientation is the mean of the observed population. 
#but I think there's something fishy going on with the rakes. 
