
library(lubridate)# lubridate is a package that allows you to access timestamps. It is used to generate the unique ids that all data in Strabo have. 

library(jsonlite)#jsonlite allows you to convert json to data frames and data frames to json. The functions fromJSON() and toJSON() are particularly useful.
library(dplyr)
source("~/Desktop/geologyGeometry/library/all.R")
setwd("~/Desktop/geologyGeometry")
# put the data.json file in the working directory of R and run the following line to import it as a data frame. You can then explore the data frame structure.
straboDataFrame = fromJSON("data.json", simplifyVector = FALSE)

# This function will generate the unique ids that every piece of data in the Strabo database will need. To generate a unique id, just call createID() with no inputs.
createID = function(){
  id = paste0(floor((as.numeric(substr(make_datetime(now()),1,10)) + runif(1)) * 10000))
  id
}

straboDataFrame$spotsDb$'16128202882890'$properties$orientation_data[[1]]$strike

ourData_csv <- read.csv("~/Desktop/geologyGeometry/ourData.csv")
ourData_csv <- filter(ourData_csv, Latitude != "NA")
#NEED TO GET trends and plunges out of rakes
#could convert strike dip rake to matrix, then find the trend and plunge of the third row in the matrix because I thnk the third row is the slip vector
#but I'm not sure the slip vector will be pointing in the right direction. If there's even a convention? maybe there's not and we just also report slip sense? but we dont report slip sense.... okay I'm stumped. 

#  for each station name, put all rows at that station in a new df, and make a newspot: straboDataFrame$spotsDb$'x', where x comes from createID()
# make spot:  straboDataFrame$spotsDb$'x'$geometry$type <- "point" and straboDataFrame$spotsDb$'x'$geometry$coordinates <- a list of doubles, probably lat then long
#for each structure in df,  straboDataFrame$spotsDb$'16128202882890'$properties$orientation_data[[i]]$strike <- df[[i]]$strike, etc


ourData_csv$station <- as.factor(ourData_csv$station)
oldStrabDf <- straboDataFrame
id_list <- list()
  
straboDataFrame$spotsDb <- vector(mode = "list", length = 0)
x = 2
for (j in levels(ourData_csv$station)){
  df <- filter(ourData_csv, station == j)
  id <- createID()
  id_list <- c(id_list, as.double(id))
  straboDataFrame$spotsDb$id <- vector(mode = "list", length = 3)
  straboDataFrame$spotsDb$id <- oldStrabDf$spotsDb$'16128202882890' #create new spot named id?
  straboDataFrame$spotsDb$id$properties$time <- '2021-10-08T21:38:08.000Z' #can change to make an actual time?
  straboDataFrame$spotsDb$id$properties$date <- '2021-10-08T21:38:08.000Z'
  straboDataFrame$spotsDb$id$properties$modified_timestamp <- as.double(id)
  straboDataFrame$spotsDb$id$properties$viewed_timestamp <- as.double(id)
  straboDataFrame$spotsDb$id$properties$name <- as.character(df$station[[1]])
  straboDataFrame$spotsDb$id$properties$orientation_data <- NULL
  straboDataFrame$spotsDb$id$properties$orientation_data <- vector(mode = "list", length = nrow(df))#mode should maybe be list? not sure if mode refers to the vector type or the type of the elements?...whats a vector?
  straboDataFrame$spotsDb$id$geometry$type <- "Point"
  straboDataFrame$spotsDb$id$geometry$coordinates <- list(df$Latitude[1], df$Longitude[1])
  straboDataFrame$spotsDb$id$type <- "Feature"

  for (i in (1:nrow(df))){
    struc <- df[i,]
    if (struc$type =="dike"){
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$type <- 'tabular_orientation'
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$quality <- "5"
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$strike <- struc$strikeDeg
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$dip <- struc$dipDeg
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$id <- id
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$feature_type <- 'intrusive'
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$instrusive_body_type <- 'dike'
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$type <- unlist(straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$type)#maybe not needed?
      }
    
    if (struc$type =="Fault"){
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$type <- 'planar_orientation'
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$quality <- "5"
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$strike <- struc$strikeDeg
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$dip <- struc$dipDeg
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$id <- id
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation <- vector(mode = "list", length = 1)
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$type <- "linear_orientation"
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$quality <- "5"
      #straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$trend <- 0
      #straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$plunge <- 0
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$Rake <- struc$rakeDeg
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$id <- id
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$associated_orientation[[1]]$feature_type <- "slickenfibers"
      straboDataFrame$spotsDb$id$properties$orientation_data[[i]]$feature_type <- 'fault' #might have to remove
    }
  }
  names(straboDataFrame$spotsDb)[length(straboDataFrame$spotsDb)] <- as.character(id)
}

straboDataFrame$projectDb$datasets$'16128202659505'$spotIds <- id_list
straboDataFrame$projectDb$project$description$magnetic_declination <- 12
straboDataFrame$projectDb$project$description$project_name <- "Block Rotation in the Tjornes Fracture Zone"

#export a JSON:
dataJson <- toJSON(straboDataFrame, dataframe = "columns", matrix ='columnmajor', Date ='ISO8601', auto_unbox = TRUE, pretty = TRUE)
write(dataJson, file="ourdata.json")


